import Log from './log';
import mqtt from 'mqtt';
// import './paho/mqttws31';

class Mqtt {

    _ip;
    _port;
    _client;
    _closeListener;
    _messageListener;

    constructor(ip, port) {
        this._ip = ip;
        this._port = port;
    }

    connect(success, fail) {
    }

    disconnect() {
    }

    subscribe(topics) {
    }

    unsubscribe(topics) {
    }

    isConnected() {
    }

    setCloseListener(l) {
        this._closeListener = l;
    }

    setMessageListener(l) {
        this._messageListener = l;
    }

}

class WebMqtt extends Mqtt {

    constructor(ip, port) {
        super(ip, port);
    }

    connect(success, fail) {
        this._client = mqtt.connect('ws://' + this._ip + ':' + this._port);
        this._client.on('connect', success);
        this._client.on('error', fail);
        this._client.on('close', (error) => {
            this._closeListener(error);
        });
        this._client.on('offline', () => {
            Log.error('WebMqtt{} - offline.');
        });
        this._client.on('reconnect', () => {
            Log.error('WebMqtt{} - reconnect.');
        });
        this._client.on('message', (topic, payload) => {
            this._messageListener(topic, payload.toString());
        });
    }

    disconnect() {
        if (!this._client) return;
        this._client.end();
    }

    subscribe(topics) {
        if (!this._client) return;
        this._client.subscribe(topics, (error, granted) => {
            if (!error) {
                console.log('subscribe(): success.');
            } else {
                console.error('subscribe(): failed.');
            }
        });
    }

    unsubscribe(topics) {
        if (!this._client) return;
        this._client.unsubscribe(topics, (error) => {
            if (!error) {
                console.log('unsubscribe(): success.');
            } else {
                console.error('unsubscribe(): failed.');
            }
        });
    }

    isConnected() {
        if (!this._client) return false;
        return this._client.connected;
    }

    isReconnecting() {
        if (!this._client) return false;
        return this._client.reconnecting;
    }

}

class MobileMqtt extends Mqtt {

    _connected = false;

    // constructor(ip, port) {
    //     super(ip, port);
    //     this._enableLocalStorage();
    //     this._client = new Paho.MQTT.Client(ip, port, 'mobile_' + Math.random().toString(16).substr(2, 8));
    //     this._client.onConnectionLost = (responseObject) => {
    //         this._connected = false;
    //         this._closeListener(responseObject);
    //     };
    //     this._client.onMessageArrived = (responseObject) => {
    //         let { destinationName, payloadString } = responseObject;
    //         this._messageListener(destinationName, payloadString);
    //     };
    // }
    //
    // _enableLocalStorage() {
    //     let localStorage = {
    //         setItem: (key, item) => {
    //             localStorage[key] = item;
    //         },
    //         getItem: (key) => {
    //             return localStorage[key];
    //         },
    //         removeItem: (key) => {
    //             delete localStorage[key];
    //         },
    //     };
    //     window.localStorage = localStorage;
    // }
    //
    // connect(success, fail) {
    //     if (!this._connected) {
    //         this._client.connect({
    //             onSuccess: () => {
    //                 this._connected = true;
    //                 success();
    //             },
    //             onFailure: (error) => {
    //                 this._connected = false;
    //                 fail(error);
    //             },
    //         });
    //     }
    // }
    //
    // disconnect() {
    //     if (this._connected) {
    //         this._client.disconnect();
    //         this._connected = false;
    //     }
    // }
    //
    // subscribe(topics) {
    //     topics.forEach((topic) => {
    //         this._client.subscribe(topic);
    //     });
    // }
    //
    // unsubscribe(topics) {
    //     topics.forEach((topic) => {
    //         this._client.unsubscribe(topic);
    //     });
    // }
    //
    // isConnected() {
    //     return this._connected;
    // }

}

export function createMqtt(platform, ip, port) {
    if (platform === 'web') {
        return new WebMqtt(ip, port);
    } else {
        return new MobileMqtt(ip, port);
    }
}