import Log from './log';

const TAG = 'token-timer';

class TokenTimer {

    _rootTimer = null;
    _isRun = false;
    _database = null;
    _api = null;

    constructor(database, api) {
        this._database = database;
        this._api = api;
    }

    start(type) {
        if (this._isRun) {
            Log.warn(TAG, 'start() - started.');
            return;
        }
        this._isRun = true;
        this._rootTimer = setInterval(() => {
            if (type === 'systemLogin') {
                this._refreshSystemToken();
            } else if (type === 'userLogin') {
                this._refreshUserToken();
            } else {
                Log.error(TAG, 'start() - unknown type.');
            }
        }, 600000);
    }

    stop() {
        if (!this._isRun) {
            Log.warn(TAG, 'stop() - no started.');
            return;
        }
        if (this._rootTimer !== null) {
            clearInterval(this._rootTimer);
            this._rootTimer = null;
        }
    }

    isRun() {
        return this._isRun;
    }

    _refreshSystemToken() {
        Log.info(TAG, 'refreshSystemToken() - start.');
        let {name, password} = this._database.load('user');
        this._api.systemLogin(name, password, {
            onSuccess: () => {
                Log.info(TAG, 'refreshSystemToken() - success.');
            },
            onFail: (error) => {
                Log.error(TAG, 'refreshSystemToken() - failed:');
                Log.error(TAG, error);
                setTimeout(() => {
                    Log.warn(TAG, 'refreshSystemToken() - failed, try again.');
                    this._refreshSystemToken();
                }, 3000);
            }
        });
    }

    _refreshUserToken() {
        Log.info(TAG, 'refreshUserToken() - start.');
        let {name, password} = this._database.load('user');
        this._api.userLogin(name, password, {
            onSuccess: () => {
                Log.info(TAG, 'refreshUserToken() - success.');
            },
            onFail: (error) => {
                Log.error(TAG, 'refreshUserToken() - failed:');
                Log.error(TAG, error);
                setTimeout(() => {
                    Log.warn(TAG, 'refreshUserToken() - failed, try again.');
                    this._refreshUserToken();
                }, 3000);
            }
        });
    }

}

export default TokenTimer;