export function buildBody(body) {
    let bodyString = '';
    let first = true;
    for (let key in body) {
        let result = key + '=' + body[key];
        if (first) {
            first = false;
            bodyString = result;
        } else {
            bodyString += '&' + result;
        }
    }
    return bodyString;
}

export function findDeviceById(devices, devId) {
    let device = null;
    for (let i = 0; i < devices.length; i++) {
        let item = devices[i];
        if (item.devId === devId) {
            device = item;
            break;
        } else {
            let children = item.children;
            if (children.length !== 0) {
                device = findDeviceById(children, devId);
                if (device != null) {
                    break;
                }
            }
        }
    }
    return device;
};

export function updateDevice(devices, devId, name, value, updTime) {
    devices.forEach((item) => {
        if (item.devId === devId) {
            let attrs = item.attrs;
            let index = attrs.findIndex((item) => {
                return item.name === name;
            });
            if (index !== -1) {
                let newAttr = {
                    name,
                    value,
                    updTime
                };
                attrs.splice(index, 1, newAttr);
            }
            return;
        } else {
            let children = item.children;
            if (children.length !== 0) {
                updateDevice(children, devId, name, value, updTime);
            }
        }
    });
};

export function findChange(oldDevices, newDevices, callback) {
    for (let i = 0; i < newDevices.length; i++) {
        let newDevice = newDevices[i];
        let isExist = false;
        for (let j = 0; j < oldDevices.length; j++) {
            let oldDevice = oldDevices[j];
            if (oldDevice.devId === newDevice.devId) {
                isExist = true;
                findChange(oldDevice.children, newDevice.children, callback);
                break;
            }
        }
        if (!isExist) {
            callback(newDevice);
        }
    }
};

export function isAttrChanged(native, cache) {
    let nativeLastModified = parseInt(native.lastModified, 10);
    let cacheLastModified = parseInt(cache.lastModified, 10);
    return nativeLastModified > cacheLastModified;
}