/*
 * File Name                   : XML解析文件
 * Author                      : Jason
 * Version                     : 1.0.0
 * Date                        : 2017/4/13
 * Revision History            : 
 * Copyright (circle) 2015-16 Axalent Solutions (Shanghai) Co., Ltd.
 * All rights reserved.
 */

export function parserSystemLogin(doc) {
    let appIdChild = doc.getElementsByTagName('appId')[0].firstChild;
    let userIdChild = doc.getElementsByTagName('userId')[0].firstChild;
    let secTokenChild = doc.getElementsByTagName('securityToken')[0].firstChild;
    let appId = appIdChild === null ? '' : appIdChild.nodeValue;
    let userId = userIdChild === null ? '' : userIdChild.nodeValue;
    let securityToken = secTokenChild === null ? '' : secTokenChild.nodeValue;
    return { appId, userId, securityToken };
};

export function parserSyslog(doc) {
    let dataListElements = doc.getElementsByTagName('tsLog');
    let logs = new Array()
    for (let i = 0; i < dataListElements.length; i++) {
        let dataElement = dataListElements[i];
        let categoryChild = dataElement.getElementsByTagName("category")[0].firstChild;
        let serviceIdChild = dataElement.getElementsByTagName("serviceId")[0].firstChild;
        let logChild = dataElement.getElementsByTagName("log")[0].firstChild;
        let timeChild = dataElement.getElementsByTagName("time")[0].firstChild;
        let category = categoryChild === null ? '' : categoryChild.nodeValue;
        let serviceId = serviceIdChild === null ? '' : serviceIdChild.nodeValue;
        let log = logChild === null ? '' : logChild.nodeValue;
        let time = timeChild === null ? '' : timeChild.nodeValue;
        logs.push({ category, serviceId, log, time, });
    }
    return logs;
};

export function parserSyslogCount(doc) {
    let dataListElements = doc.getElementsByTagName('count');
    let count = dataListElements[0].childNodes[0].nodeValue;
    return count;
};

export function parserUserLogin(doc) {
    let userIdChild = doc.getElementsByTagName('userId')[0].firstChild;
    let secTokenChild = doc.getElementsByTagName('securityToken')[0].firstChild;
    let userId = userIdChild === null ? '' : userIdChild.nodeValue;
    let securityToken = secTokenChild === null ? '' : secTokenChild.nodeValue;
    return { userId, securityToken };
};

export function parserRegisterUser(doc) {
    let userIdChild = doc.getElementsByTagName('userId')[0].firstChild;
    let userId = userIdChild === null ? '' : userIdChild.nodeValue;
    return userId;
}

export function parserRetCode(doc) {
    let retCodeChild = doc.getElementsByTagName('retCode')[0].firstChild;
    let retCode = retCodeChild === null ? '' : retCodeChild.nodeValue;
    return retCode;
};

export function parserUserValueList(doc) {
    let valistElements = doc.getElementsByTagName('valist');
    let attrs = new Array();
    for (let i = 0; i < valistElements.length; i++) {
        let valistElement = valistElements[i];
        let nameElement = valistElement.getElementsByTagName("name")[0].firstChild;
        let valueElement = valistElement.getElementsByTagName("value")[0].firstChild;
        let name = nameElement === null ? '' : nameElement.nodeValue;
        let value = valueElement === null ? '' : valueElement.nodeValue;
        let attr = { name, value };
        attrs.push(attr);
    }
    return attrs;
};

export function parserDeviceTypeList(doc) {
    let typeNameListElements = doc.getElementsByTagName('typeNameList');
    let deviceTypes = new Array();
    for (let i = 0; i < typeNameListElements.length; i++) {
        let typeNameListElement = typeNameListElements[i];
        let idElement = typeNameListElement.getElementsByTagName("id")[0].firstChild;
        let nameElement = typeNameListElement.getElementsByTagName("name")[0].firstChild;
        let displayNameElement = typeNameListElement.getElementsByTagName("displayName")[0].firstChild;
        let id = idElement === null ? '' : idElement.nodeValue;
        let name = nameElement === null ? '' : nameElement.nodeValue;
        let displayName = displayNameElement === null ? '' : displayNameElement.nodeValue;
        let deviceType = { id, name, displayName };
        deviceTypes.push(deviceType);
    }
    return deviceTypes;
};

export function parserDeviceList(doc) {
    let parserChildNodes = (childNodes, parentId) => {
        let device = { parentId, children: [], typeName: '', attrs: [] };
        for (let j = 0; j < childNodes.length; j++) {
            let childNode = childNodes[j];
            let childName = childNode.nodeName;
            let childValue = childNode.firstChild !== null ? childNode.firstChild.nodeValue : '';
            if (childName === 'devList') {
                device.children.push(parserChildNodes(childNode.childNodes, device.devId));
            } else {
                device[childName] = childValue;
            }
        }
        return device;
    }
    let childNodes = doc.childNodes[0].childNodes;
    let devices = new Array();
    for (let i = 0; i < childNodes.length; i++) {
        let childNode = childNodes[i];
        devices.push(parserChildNodes(childNode.childNodes, ''));
    }
    return devices;
};

export function parserCreateVirtualDevice(doc) {
    let deviceIdChild = doc.getElementsByTagName('deviceId')[0].firstChild;
    let deviceId = deviceIdChild === null ? '' : deviceIdChild.nodeValue;
    return deviceId;
};

export function parserDeviceAttributesWithValues(doc) {
    let typeIdChild = doc.getElementsByTagName('typeId')[0].firstChild;
    let typeNameChild = doc.getElementsByTagName('typeName')[0].firstChild;
    let presenceInfoChild = doc.getElementsByTagName('presenceInfo')[0].firstChild;
    let typeId = typeIdChild == null ? '' : typeIdChild.nodeValue;
    let typeName = typeNameChild == null ? '' : typeNameChild.nodeValue;
    let presenceInfo = presenceInfoChild == null ? '0' : presenceInfoChild.nodeValue;
    let attrListElements = doc.getElementsByTagName('attrList');
    let attrs = new Array();
    for (let i = 0; i < attrListElements.length; i++) {
        var attrElement = attrListElements[i];
        var nameChild = attrElement.getElementsByTagName("name")[0].firstChild;
        var valueChild = attrElement.getElementsByTagName("value")[0].firstChild;
        var updTimeChild = attrElement.getElementsByTagName("updTime")[0].firstChild;
        let attr = {
            name: nameChild === null ? '' : nameChild.nodeValue,
            value: valueChild === null ? '' : valueChild.nodeValue,
            updTime: updTimeChild === null ? '' : updTimeChild.nodeValue,
        };
        attrs.push(attr);
    }
    return { typeId, typeName, presenceInfo, attrs };
};

export function parserDeviceAttribute(doc) {
    let valueChild = doc.getElementsByTagName('value')[0].firstChild;
    let updTimeChild = doc.getElementsByTagName('updTime')[0].firstChild;
    let value = valueChild === null ? '' : valueChild.nodeValue;
    let updTime = updTimeChild === null ? '' : updTimeChild.nodeValue;
    return { value, updTime };
};

export function parserDeviceTS2(doc) {
    let devIdChild = doc.getElementsByTagName('devId')[0].firstChild;
    let propNameChild = doc.getElementsByTagName('propName')[0].firstChild;
    let devId = devIdChild === null ? '' : devIdChild.nodeValue;
    let propName = propNameChild === null ? '' : propNameChild.nodeValue;
    let dataListElements = doc.getElementsByTagName('tsData');
    let tsDatas = new Array()
    for (let i = 0; i < dataListElements.length; i++) {
        let dataElement = dataListElements[i];
        let idChild = dataElement.getElementsByTagName("id")[0].firstChild;
        let strValueChild = dataElement.getElementsByTagName("strValue")[0].firstChild;
        let timeChild = dataElement.getElementsByTagName("time")[0].firstChild;
        let attachedChild = dataElement.getElementsByTagName("attached")[0].firstChild;
        let id = idChild === null ? '' : idChild.nodeValue;
        let strValue = strValueChild === null ? '' : strValueChild.nodeValue;
        let time = timeChild === null ? '' : timeChild.nodeValue;
        let attached = attachedChild === null ? '' : attachedChild.nodeValue;
        let tData = { id, strValue, time, attached };
        tsDatas.push(tData);
    }
    return { devId, propName, tsDatas };
};

export function parserDeviceTS3(doc) {
    let dataListElements = doc.getElementsByTagName('tsData');
    let tsDatas = new Array()
    for (let i = 0; i < dataListElements.length; i++) {
        let dataElement = dataListElements[i];
        let idChild = dataElement.getElementsByTagName("id")[0].firstChild;
        let devIdChild = dataElement.getElementsByTagName("devId")[0].firstChild;
        let nameChild = dataElement.getElementsByTagName("name")[0].firstChild;
        let strValueChild = dataElement.getElementsByTagName("strValue")[0].firstChild;
        let timeChild = dataElement.getElementsByTagName("time")[0].firstChild;
        let attachedChild = dataElement.getElementsByTagName("attached")[0].firstChild;
        let id = idChild === null ? '' : idChild.nodeValue;
        let devId = devIdChild === null ? '' : devIdChild.nodeValue;
        let name = nameChild === null ? '' : nameChild.nodeValue;
        let strValue = strValueChild === null ? '' : strValueChild.nodeValue;
        let time = timeChild === null ? '' : timeChild.nodeValue;
        let attached = attachedChild === null ? '' : attachedChild.nodeValue;
        let tData = { id, devId, name, strValue, time, attached };
        tsDatas.push(tData);
    }
    return tsDatas;
};

export function parserDeviceTS3Count(doc) {
    let dataListElements = doc.getElementsByTagName('count');
    let count = dataListElements[0].childNodes[0].nodeValue
    return count;
};

export function parserRequestError(doc) {
    let errorCodeChild = doc.getElementsByTagName('errorCode')[0].firstChild;
    let errorMsgChild = doc.getElementsByTagName('errorMsg')[0].firstChild;
    let code = errorCodeChild === null ? '' : errorCodeChild.nodeValue;
    let msg = errorMsgChild === null ? '' : errorMsgChild.nodeValue;
    return { code, msg };
};

export function parserDeviceAuth(doc) {
    let devIdChild = doc.getElementsByTagName('devId')[0].firstChild;
    let devId = devIdChild === null ? '' : devIdChild.nodeValue;
    return devId;
};

export function parserDeviceUserList(doc) {
    let childNodes = doc.childNodes[0].childNodes;
    let users = new Array();
    for (let i = 0; i < childNodes.length; i++) {
        let childNode = childNodes[i];
        let childNodes2 = childNode.childNodes;
        let user = {};
        for (let j = 0; j < childNodes2.length; j++) {
            let childNode2 = childNodes2[j];
            let childName = childNode2.nodeName;
            let childValue = childNode2.firstChild !== null ? childNode2.firstChild.nodeValue : '';
            user[childName] = childValue;
        }
        users.push(user);
    }
    return users;
};

export function parserTouchList(doc) {
    let childNodes = doc.childNodes[0].childNodes;
    let touchs = new Array();
    for (let i = 0; i < childNodes.length; i++) {
        let childNode = childNodes[i];
        let childNodes2 = childNode.childNodes;
        let touch = {};
        for (let j = 0; j < childNodes2.length; j++) {
            let childNode2 = childNodes2[j];
            let childName = childNode2.nodeName;
            let childValue = childNode2.firstChild !== null ? childNode2.firstChild.nodeValue : '';
            touch[childName] = childValue;
        }
        touchs.push(touch);
    }
    return touchs;
};

export function parserUserInfoByName(doc) {
    let userIdChild = doc.getElementsByTagName('userId')[0].firstChild;
    let nameChild = doc.getElementsByTagName('name')[0].firstChild;
    let userId = userIdChild === null ? '' : userIdChild.nodeValue;
    let name = nameChild === null ? '' : nameChild.nodeValue;
    return { userId, name };
};

export function parserContactsList(doc) {
    let childNodes = doc.childNodes[0].childNodes;
    let contacts = new Array();
    for (let i = 0; i < childNodes.length; i++) {
        let childNode = childNodes[i];
        let childNodes2 = childNode.childNodes;
        let contact = {};
        for (let j = 0; j < childNodes2.length; j++) {
            let childNode2 = childNodes2[j];
            let childName = childNode2.nodeName;
            let childValue = childNode2.firstChild !== null ? childNode2.firstChild.nodeValue : '';
            contact[childName] = childValue;
        }
        contacts.push(contact);
    }
    return contacts;
};


